/*
 * This file is part of jSpeed.
 *
 * jSpeed is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * jSpeed is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with jSpeed.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef BLUREFFECT_H
#define BLUREFFECT_H

#include "effect.h"

class QGraphicsBlurEffect;

class BlurEffect : public Effect
{
public:
    enum Attribute {RADIUS, ATTRIBUTE_COUNT};
    BlurEffect();
    virtual bool setAttribute(QString const& name, QString const& value);
    virtual void apply(GraphicsElement* item);

private:
    QGraphicsBlurEffect* effect_;
};

#endif
